@@ -16,7 +16,7 @@ INSERT INTO agent_versions (dev_type, version_major, version_minor, version_patc
 (4, 1, 1, 0, true);
 
 INSERT INTO product_versions (id, actual, version_major, version_minor, version_patchlevel, version_string, major, beta, notification, force_display, release_date, description) values 
-(1, true, 1, 2, 0, 'Afterparty 2 (Keeper BETA 2)', false, true, true, true, '2025-09-30',
+(1, true, 1, 3, 0, 'Afterparty 3 (Keeper BETA 3)', false, true, true, true, '2025-10-20',
 '<h5>Release notes</h5>'
 '<b>The release notes below are not completely relevant to the BETA version you are running, these are preparations for the Dwarfguard 2.0.0 Keeper version.</b>'
 '<h6>Server:</h6><ul>'
@@ -36,6 +36,7 @@ INSERT INTO product_versions (id, actual, version_major, version_minor, version_
 '<li>Added Reboot button into Devices table actions to schedule a reboot for a particular device.</li>'
 '<li>List of triggered devices can now be accessed directly from alert definition table.</li>'
 '<li>Improvements in UI - horizontal scrolling, ordering fix</li>'
+'<li>If self-signed certificate is created (distributed to devices) it now contains CA certificate as well.</li>'
 '<li>Updated Symfony.</li>'
 '<li>Incorporated all fixes from stable support releases 1.0.1 - 1.0.4</li>'
 '<li></li>'
@@ -50,14 +51,14 @@ INSERT INTO product_versions (id, actual, version_major, version_minor, version_
 '<li></li>'
 '</ul>');
 
-INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.0.4 (+339)');
+INSERT INTO product_flags(id, version, description) values ('buildtag', 1, 'v1.2.0_BETA (+7)');
 INSERT INTO product_flags(id, version, description) values ('about_info', 1, 'Dwarfguard - Monitoring, Alerting, Management and Automation System
 
-Build tag: v1.0.4 (+339)
-Build date: 2025_09_30__14_43_01
+Build tag: v1.2.0_BETA (+7)
+Build date: 2025_10_08__17_36_18
 
 Build components:
-(mamas): v1.0.4 (+216)
-(mamasbig): v1.0.4 (+9)
-(mamasweb): v1.0.4 (+114)
-(mamasnotify): v1.0.4');
+(mamas): v1.2.0_BETA (+6)
+(mamasbig): v1.2.0_BETA (+1)
+(mamasweb): v1.2.0_BETA
+(mamasnotify): v1.2.0_BETA');
