@@ -183,6 +183,12 @@ def activesim(s):
             return "2nd"
     return "1st"
 
+def ignoreNA(s):
+    if s is not None:
+        if s == "N/A" or s == "n/a":
+            return None
+    return s
+
 def quote(string):
     return '"'+str(string)+'"'
 
@@ -191,6 +197,7 @@ fdict = {
         'u': uptime,
         'v': voltage,
         's': activesim,
+        'i': ignoreNA,
         '"': quote
         }
 
@@ -205,7 +212,7 @@ oids_advantech = [
         ( "1.3.6.1.2.1.1.2", "STAT", "various", "snmphint=", True, "c"), # prodtype (must be 1.3.6.1.4.1.30140.* for advantech)
         ( "1.3.6.1.2.1.1.3", "STAT", "various", "uptime=", False, 'u"'),  # sysUpTime (/100 seconds)
         ( "1.3.6.1.2.1.1.5", "STAT", "various", "snmpname=", False, '"'),        # SysName
-        ( "1.3.6.1.4.1.30140.3.3", "STAT", "status sys", "Temperature     : ", True, None),  # temperature
+        ( "1.3.6.1.4.1.30140.3.3", "STAT", "status sys", "Temperature      : ", True, None),  # temperature
         ( "1.3.6.1.4.1.30140.3.4", "STAT", "status sys", "Supply Voltage   : ", True, "v"), # Voltage (mV)
         ( "1.3.6.1.4.1.30140.3.6", "STAT", "status sys", "CPU Usage       : ", True, None), # CPU usage (%)
         ( "1.3.6.1.4.1.30140.3.9", "STAT", "various", "memavail=", True, None),  # RAM free (bytes)
@@ -218,7 +225,7 @@ oids_advantech = [
         ( "1.3.6.1.4.1.30140.4.30", "STAT", "status mobile", "RSSI : ", True, None), # Signal strength (RSSI)
         ( "1.3.6.1.4.1.30140.6.1", "STAT", "status sys", "Product Name     : ", False, None), # Product
         ( "1.3.6.1.4.1.30140.6.2", "STAT", "status sys", "Firmware Version : ", False, None), # Firmware version
-        ( "1.3.6.1.4.1.30140.6.3", "STAT", "status sys", "Serial Number    : ", False, None), # Serial NO
+        ( "1.3.6.1.4.1.30140.6.3", "STAT", "status sys", "Serial Number    : ", False, "i"), # Serial NO
         ( "1.3.6.1.4.1.30140.6.4", "LONGSTAT", "status module", "IMEI           : ", False, None), # IMEI
         ( "1.3.6.1.4.1.30140.6.7", "LONGSTAT", "status module", "ICCID          : ", False, None), # ICCID
 ]
@@ -318,7 +325,8 @@ async def getdevice(target_ip, oidmap, creds, logger, protov2c=True):
                     myf=get_func(char)
                     if myf is not None:
                         outval=myf(outval)
-            addstuff(resdict, item[0], item[1], item[2], item[3], str(outval), dumplog)
+            if outval is not None:
+                addstuff(resdict, item[0], item[1], item[2], item[3], str(outval), dumplog)
     addstuff(resdict, None, "VARS", None, None, "g_appversion="+str(agent_version), dumplog)
     addstuff(resdict, None, "VARS", None, None, 'g_mysystem="SNMP device"', dumplog)
     addstuff(resdict, None, "VARS", None, None, "g_machid=\""+get_snmp_machid(target_ip)+"\"", dumplog)
