@@ -7,16 +7,18 @@ namespace App\Entity\Alert;
 use App\Entity\Device\Device;
 use App\Entity\MonitoringGroup\MonitoringGroup;
 use App\Entity\Types\TypesOperator;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'alerts')]
 #[ORM\Entity]
+#[ORM\HasLifecycleCallbacks]
 class Alert
 {
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'id', type: 'integer')]
+    #[ORM\Column(name: 'id', type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -24,7 +26,7 @@ class Alert
     /**
      * @var string|null
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: true)]
     public ?string $name = null;
 
     /**
@@ -44,7 +46,7 @@ class Alert
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'smallint', nullable: true, options: ['default' => 1])]
+    #[ORM\Column(type: Types::SMALLINT, nullable: true, options: ['default' => 1])]
     public ?int $targetAmount = null;
 
     /**
@@ -64,7 +66,7 @@ class Alert
     /**
      * @var int
      */
-    #[ORM\Column(type: 'integer', nullable: true, options: ['default' => 120])]
+    #[ORM\Column(type: Types::INTEGER, nullable: true, options: ['default' => 120])]
     public int $evaluateInterval = 120;
 
     /**
@@ -84,61 +86,61 @@ class Alert
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'num_first', type: 'float', nullable: true)]
+    #[ORM\Column(name: 'num_first', type: Types::FLOAT, nullable: true)]
     public ?float $numFirst = null;
 
     /**
      * @var float|null
      */
-    #[ORM\Column(name: 'num_second', type: 'float', nullable: true)]
+    #[ORM\Column(name: 'num_second', type: Types::FLOAT, nullable: true)]
     public ?float $numSecond = null;
 
     /**
      * @var \DateTime
      */
-    #[ORM\Column(name: 'last_trigger_time ', type: 'datetime', options: ['default' => null])]
+    #[ORM\Column(name: 'last_trigger_time ', type: Types::DATETIME_MUTABLE, options: ['default' => null])]
     public ?\DateTime $lastTriggerTime = null;
 
     /**
      * @var \DateTime
      */
-    #[ORM\Column(name: 'last_notification_time ', type: 'datetime', options: ['default' => null])]
+    #[ORM\Column(name: 'last_notification_time ', type: Types::DATETIME_MUTABLE, options: ['default' => null])]
     public ?\DateTime $lastNotificationTime = null;
 
     /**
      * @var bool
      */
-    #[ORM\Column(type: 'boolean', nullable: false, options: ['default' => false])]
+    #[ORM\Column(type: Types::BOOLEAN, nullable: false, options: ['default' => false])]
     public bool $enabled = false;
 
     /**
      * @var bool
      */
-    #[ORM\Column(type: 'boolean', nullable: false, options: ['default' => false])]
+    #[ORM\Column(type: Types::BOOLEAN, nullable: false, options: ['default' => false])]
     public bool $active = false;
 
     /**
      * @var int
      */
-    #[ORM\Column(type: 'smallint', nullable: true, options: ['default' => '0'])]
+    #[ORM\Column(type: Types::SMALLINT, nullable: true, options: ['default' => '0'])]
     public int $counter = 0;
 
     /**
      * @var int
      */
-    #[ORM\Column(type: 'smallint', nullable: true, options: ['default' => '0'])]
+    #[ORM\Column(type: Types::SMALLINT, nullable: true, options: ['default' => '0'])]
     public int $triggered = 0;
 
     /**
      * @var bool
      */
-    #[ORM\Column(type: 'boolean', nullable: false, options: ['default' => false])]
+    #[ORM\Column(type: Types::BOOLEAN, nullable: false, options: ['default' => false])]
     public bool $deleted = false;
 
     /**
      * @var int
      */
-    #[ORM\Column(type: 'integer', nullable: true)]
+    #[ORM\Column(type: Types::INTEGER, nullable: true)]
     public int $version;
 
     /**
