@@ -7,6 +7,7 @@ namespace App\Entity\Alert;
 use App\Entity\Types\TypesValueType;
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'alert_target_spec')]
@@ -16,7 +17,7 @@ class AlertTargetSpec implements \Stringable
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -24,7 +25,7 @@ class AlertTargetSpec implements \Stringable
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
     public string $name;
 
     /**
@@ -58,7 +59,7 @@ class AlertTargetSpec implements \Stringable
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 64, unique: true, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 64, unique: true, nullable: false)]
     public string $hint;
 
     /**
