@@ -6,6 +6,7 @@ namespace App\Entity\ConfigProfile;
 
 use Doctrine\Common\Collections\ArrayCollection;
 use Doctrine\Common\Collections\Collection;
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'config_key_groups')]
@@ -15,7 +16,7 @@ class ConfigProfileKeyGroup
     /**
      * @var int|null
      */
-    #[ORM\Column(name: 'id', type: 'integer')]
+    #[ORM\Column(name: 'id', type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -23,7 +24,7 @@ class ConfigProfileKeyGroup
     /**
      * @var string
      */
-    #[ORM\Column(type: 'string', length: 64, nullable: false)]
+    #[ORM\Column(type: Types::STRING, length: 64, nullable: false)]
     public string $groupName;
 
     /**
@@ -60,7 +61,7 @@ class ConfigProfileKeyGroup
     }
 
     /**
-     * @return Collection
+     * @return Collection<int, \App\Entity\ConfigProfile\ConfigProfileKey>
      */
     public function getConfigProfileKeys(): Collection
     {
