@@ -4,6 +4,7 @@ declare(strict_types=1);
 
 namespace App\Entity\Device;
 
+use Doctrine\DBAL\Types\Types;
 use Doctrine\ORM\Mapping as ORM;
 
 #[ORM\Table(name: 'device_models')]
@@ -13,7 +14,7 @@ class DeviceModel {
     /**
      * @var int|null
      */
-    #[ORM\Column(type: 'integer')]
+    #[ORM\Column(type: Types::INTEGER)]
     #[ORM\Id]
     #[ORM\GeneratedValue(strategy: 'AUTO')]
     private ?int $id = null;
@@ -21,7 +22,7 @@ class DeviceModel {
     /**
      * @var string|null
      */
-    #[ORM\Column(type: 'string', length: 128, nullable: true)]
+    #[ORM\Column(type: Types::STRING, length: 128, nullable: true)]
     public ?string $model = null;
 
     /**
